@@ -2,12 +2,9 @@ from django.forms import ValidationError
 
 from allauth.account import app_settings as account_settings
 from allauth.account.adapter import get_adapter as get_account_adapter
-from allauth.account.internal.flows.signup import prevent_enumeration
-from allauth.account.utils import (
-    assess_unique_email,
-    complete_signup,
-    user_username,
-)
+from allauth.account.internal.flows.manage_email import assess_unique_email
+from allauth.account.internal.flows.signup import complete_signup, prevent_enumeration
+from allauth.account.utils import user_username
 from allauth.core.exceptions import SignupClosedException
 from allauth.core.internal.httpkit import headed_redirect_response
 from allauth.socialaccount import app_settings
@@ -42,6 +39,14 @@ def process_auto_signup(request, sociallogin):
     auto_signup = get_adapter().is_auto_signup_allowed(request, sociallogin)
     if not auto_signup:
         return False, None
+    auto_signup, resp = process_auto_signup_email(request, sociallogin)
+    if not auto_signup:
+        return False, resp
+    auto_signup, resp = process_auto_signup_phone(request, sociallogin)
+    return auto_signup, resp
+
+
+def process_auto_signup_email(request, sociallogin):
     email = None
     if sociallogin.email_addresses:
         email = sociallogin.email_addresses[0].email
@@ -50,7 +55,7 @@ def process_auto_signup(request, sociallogin):
         assessment = assess_unique_email(email)
         if assessment is True:
             # Auto signup is fine.
-            pass
+            auto_signup = True
         elif assessment is False:
             # Oops, another user already has this address.  We cannot simply
             # connect this social account to the existing user. Reason is
@@ -64,20 +69,37 @@ def process_auto_signup(request, sociallogin):
             # address conflict only after posting whereas we detected it
             # here already.
         else:
-            assert assessment is None
+            assert assessment is None  # nosec
             # Prevent enumeration is properly turned on, meaning, we cannot
             # show the signup form to allow the user to input another email
             # address. Instead, we're going to send the user an email that
             # the account already exists, and on the outside make it appear
             # as if an email verification mail was sent.
-            resp = prevent_enumeration(request, email)
+            resp = prevent_enumeration(request, email=email)
             return False, resp
     elif app_settings.EMAIL_REQUIRED:
         # Nope, email is required and we don't have it yet...
         auto_signup = False
+    else:
+        auto_signup = True
     return auto_signup, None
 
 
+def process_auto_signup_phone(request, sociallogin):
+    # At this point, email is not required, or, we have a unique email.  Let's
+    # check the phone number.
+    phone_field = account_settings.SIGNUP_FIELDS.get("phone")
+    if not phone_field or not phone_field["required"]:
+        return True, None
+    if not sociallogin.phone:
+        return False, None
+    # If the phone is already taken?
+    existing_user = get_account_adapter().get_user_by_phone(sociallogin.phone)
+    if existing_user:
+        return False, None
+    return True, None
+
+
 def process_signup(request, sociallogin):
     if not get_adapter().is_open_for_signup(request, sociallogin):
         raise SignupClosedException()
@@ -107,8 +129,8 @@ def process_signup(request, sociallogin):
 def complete_social_signup(request, sociallogin):
     return complete_signup(
         request,
-        sociallogin.user,
-        app_settings.EMAIL_VERIFICATION,
-        sociallogin.get_redirect_url(request),
+        user=sociallogin.user,
+        email_verification=app_settings.EMAIL_VERIFICATION,
+        redirect_url=sociallogin.get_redirect_url(request),
         signal_kwargs={"sociallogin": sociallogin},
     )
